@@ -1,63 +1,63 @@
 #![allow(non_snake_case, non_camel_case_types, non_upper_case_globals, clashing_extern_declarations, clippy::all)]
 #[link(name = "windows")]
 extern "system" {
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsAdd(dfsentrypath: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, sharename: ::windows_sys::core::PCWSTR, comment: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsAddFtRoot(servername: ::windows_sys::core::PCWSTR, rootshare: ::windows_sys::core::PCWSTR, ftdfsname: ::windows_sys::core::PCWSTR, comment: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsAddRootTarget(pdfspath: ::windows_sys::core::PCWSTR, ptargetpath: ::windows_sys::core::PCWSTR, majorversion: u32, pcomment: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsAddStdRoot(servername: ::windows_sys::core::PCWSTR, rootshare: ::windows_sys::core::PCWSTR, comment: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsEnum(dfsname: ::windows_sys::core::PCWSTR, level: u32, prefmaxlen: u32, buffer: *mut *mut u8, entriesread: *mut u32, resumehandle: *mut u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsGetClientInfo(dfsentrypath: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, sharename: ::windows_sys::core::PCWSTR, level: u32, buffer: *mut *mut u8) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
-    pub fn NetDfsGetFtContainerSecurity(domainname: ::windows_sys::core::PCWSTR, securityinformation: u32, ppsecuritydescriptor: *mut *mut super::super::Security::SECURITY_DESCRIPTOR, lpcbsecuritydescriptor: *mut u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+    #[cfg(feature = "Win32_Security")]
+    pub fn NetDfsGetFtContainerSecurity(domainname: ::windows_sys::core::PCWSTR, securityinformation: u32, ppsecuritydescriptor: *mut super::super::Security::PSECURITY_DESCRIPTOR, lpcbsecuritydescriptor: *mut u32) -> u32;
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsGetInfo(dfsentrypath: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, sharename: ::windows_sys::core::PCWSTR, level: u32, buffer: *mut *mut u8) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
-    pub fn NetDfsGetSecurity(dfsentrypath: ::windows_sys::core::PCWSTR, securityinformation: u32, ppsecuritydescriptor: *mut *mut super::super::Security::SECURITY_DESCRIPTOR, lpcbsecuritydescriptor: *mut u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
-    pub fn NetDfsGetStdContainerSecurity(machinename: ::windows_sys::core::PCWSTR, securityinformation: u32, ppsecuritydescriptor: *mut *mut super::super::Security::SECURITY_DESCRIPTOR, lpcbsecuritydescriptor: *mut u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+    #[cfg(feature = "Win32_Security")]
+    pub fn NetDfsGetSecurity(dfsentrypath: ::windows_sys::core::PCWSTR, securityinformation: u32, ppsecuritydescriptor: *mut super::super::Security::PSECURITY_DESCRIPTOR, lpcbsecuritydescriptor: *mut u32) -> u32;
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+    #[cfg(feature = "Win32_Security")]
+    pub fn NetDfsGetStdContainerSecurity(machinename: ::windows_sys::core::PCWSTR, securityinformation: u32, ppsecuritydescriptor: *mut super::super::Security::PSECURITY_DESCRIPTOR, lpcbsecuritydescriptor: *mut u32) -> u32;
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsGetSupportedNamespaceVersion(origin: DFS_NAMESPACE_VERSION_ORIGIN, pname: ::windows_sys::core::PCWSTR, ppversioninfo: *mut *mut DFS_SUPPORTED_NAMESPACE_VERSION_INFO) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsMove(olddfsentrypath: ::windows_sys::core::PCWSTR, newdfsentrypath: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsRemove(dfsentrypath: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, sharename: ::windows_sys::core::PCWSTR) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsRemoveFtRoot(servername: ::windows_sys::core::PCWSTR, rootshare: ::windows_sys::core::PCWSTR, ftdfsname: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsRemoveFtRootForced(domainname: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, rootshare: ::windows_sys::core::PCWSTR, ftdfsname: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsRemoveRootTarget(pdfspath: ::windows_sys::core::PCWSTR, ptargetpath: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsRemoveStdRoot(servername: ::windows_sys::core::PCWSTR, rootshare: ::windows_sys::core::PCWSTR, flags: u32) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsSetClientInfo(dfsentrypath: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, sharename: ::windows_sys::core::PCWSTR, level: u32, buffer: *const u8) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
-    pub fn NetDfsSetFtContainerSecurity(domainname: ::windows_sys::core::PCWSTR, securityinformation: u32, psecuritydescriptor: *const super::super::Security::SECURITY_DESCRIPTOR) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+    #[cfg(feature = "Win32_Security")]
+    pub fn NetDfsSetFtContainerSecurity(domainname: ::windows_sys::core::PCWSTR, securityinformation: u32, psecuritydescriptor: super::super::Security::PSECURITY_DESCRIPTOR) -> u32;
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
     pub fn NetDfsSetInfo(dfsentrypath: ::windows_sys::core::PCWSTR, servername: ::windows_sys::core::PCWSTR, sharename: ::windows_sys::core::PCWSTR, level: u32, buffer: *const u8) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
-    pub fn NetDfsSetSecurity(dfsentrypath: ::windows_sys::core::PCWSTR, securityinformation: u32, psecuritydescriptor: *const super::super::Security::SECURITY_DESCRIPTOR) -> u32;
-    #[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-    #[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
-    pub fn NetDfsSetStdContainerSecurity(machinename: ::windows_sys::core::PCWSTR, securityinformation: u32, psecuritydescriptor: *const super::super::Security::SECURITY_DESCRIPTOR) -> u32;
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+    #[cfg(feature = "Win32_Security")]
+    pub fn NetDfsSetSecurity(dfsentrypath: ::windows_sys::core::PCWSTR, securityinformation: u32, psecuritydescriptor: super::super::Security::PSECURITY_DESCRIPTOR) -> u32;
+    #[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+    #[cfg(feature = "Win32_Security")]
+    pub fn NetDfsSetStdContainerSecurity(machinename: ::windows_sys::core::PCWSTR, securityinformation: u32, psecuritydescriptor: super::super::Security::PSECURITY_DESCRIPTOR) -> u32;
 }
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_ADD_VOLUME: u32 = 1u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_FORCE_REMOVE: u32 = 2147483648u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_GET_PKT_ENTRY_STATE_ARG {
     pub DfsEntryPathLen: u16,
     pub ServerNameLen: u16,
@@ -72,7 +72,7 @@ impl ::core::clone::Clone for DFS_GET_PKT_ENTRY_STATE_ARG {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_1 {
     pub EntryPath: ::windows_sys::core::PWSTR,
 }
@@ -83,7 +83,7 @@ impl ::core::clone::Clone for DFS_INFO_1 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_100 {
     pub Comment: ::windows_sys::core::PWSTR,
 }
@@ -94,7 +94,7 @@ impl ::core::clone::Clone for DFS_INFO_100 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_101 {
     pub State: u32,
 }
@@ -105,7 +105,7 @@ impl ::core::clone::Clone for DFS_INFO_101 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_102 {
     pub Timeout: u32,
 }
@@ -116,7 +116,7 @@ impl ::core::clone::Clone for DFS_INFO_102 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_103 {
     pub PropertyFlagMask: u32,
     pub PropertyFlags: u32,
@@ -128,7 +128,7 @@ impl ::core::clone::Clone for DFS_INFO_103 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_104 {
     pub TargetPriority: DFS_TARGET_PRIORITY,
 }
@@ -139,7 +139,7 @@ impl ::core::clone::Clone for DFS_INFO_104 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_105 {
     pub Comment: ::windows_sys::core::PWSTR,
     pub State: u32,
@@ -154,7 +154,7 @@ impl ::core::clone::Clone for DFS_INFO_105 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_106 {
     pub State: u32,
     pub TargetPriority: DFS_TARGET_PRIORITY,
@@ -166,8 +166,8 @@ impl ::core::clone::Clone for DFS_INFO_106 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+#[cfg(feature = "Win32_Security")]
 pub struct DFS_INFO_107 {
     pub Comment: ::windows_sys::core::PWSTR,
     pub State: u32,
@@ -175,33 +175,33 @@ pub struct DFS_INFO_107 {
     pub PropertyFlagMask: u32,
     pub PropertyFlags: u32,
     pub SdLengthReserved: u32,
-    pub pSecurityDescriptor: *mut super::super::Security::SECURITY_DESCRIPTOR,
+    pub pSecurityDescriptor: super::super::Security::PSECURITY_DESCRIPTOR,
 }
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::marker::Copy for DFS_INFO_107 {}
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::clone::Clone for DFS_INFO_107 {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+#[cfg(feature = "Win32_Security")]
 pub struct DFS_INFO_150 {
     pub SdLengthReserved: u32,
-    pub pSecurityDescriptor: *mut super::super::Security::SECURITY_DESCRIPTOR,
+    pub pSecurityDescriptor: super::super::Security::PSECURITY_DESCRIPTOR,
 }
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::marker::Copy for DFS_INFO_150 {}
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::clone::Clone for DFS_INFO_150 {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct DFS_INFO_1_32 {
     pub EntryPath: u32,
@@ -215,7 +215,7 @@ impl ::core::clone::Clone for DFS_INFO_1_32 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_2 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -229,7 +229,7 @@ impl ::core::clone::Clone for DFS_INFO_2 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_200 {
     pub FtDfsName: ::windows_sys::core::PWSTR,
 }
@@ -240,7 +240,7 @@ impl ::core::clone::Clone for DFS_INFO_200 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct DFS_INFO_2_32 {
     pub EntryPath: u32,
@@ -257,7 +257,7 @@ impl ::core::clone::Clone for DFS_INFO_2_32 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_3 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -272,7 +272,7 @@ impl ::core::clone::Clone for DFS_INFO_3 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_300 {
     pub Flags: u32,
     pub DfsName: ::windows_sys::core::PWSTR,
@@ -284,7 +284,7 @@ impl ::core::clone::Clone for DFS_INFO_300 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct DFS_INFO_3_32 {
     pub EntryPath: u32,
@@ -302,7 +302,7 @@ impl ::core::clone::Clone for DFS_INFO_3_32 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_4 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -319,7 +319,7 @@ impl ::core::clone::Clone for DFS_INFO_4 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct DFS_INFO_4_32 {
     pub EntryPath: u32,
@@ -339,7 +339,7 @@ impl ::core::clone::Clone for DFS_INFO_4_32 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_5 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -357,7 +357,7 @@ impl ::core::clone::Clone for DFS_INFO_5 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_50 {
     pub NamespaceMajorVersion: u32,
     pub NamespaceMinorVersion: u32,
@@ -370,7 +370,7 @@ impl ::core::clone::Clone for DFS_INFO_50 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_6 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -389,7 +389,7 @@ impl ::core::clone::Clone for DFS_INFO_6 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_INFO_7 {
     pub GenerationGuid: ::windows_sys::core::GUID,
 }
@@ -400,8 +400,8 @@ impl ::core::clone::Clone for DFS_INFO_7 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+#[cfg(feature = "Win32_Security")]
 pub struct DFS_INFO_8 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -411,20 +411,20 @@ pub struct DFS_INFO_8 {
     pub PropertyFlags: u32,
     pub MetadataSize: u32,
     pub SdLengthReserved: u32,
-    pub pSecurityDescriptor: *mut super::super::Security::SECURITY_DESCRIPTOR,
+    pub pSecurityDescriptor: super::super::Security::PSECURITY_DESCRIPTOR,
     pub NumberOfStorages: u32,
 }
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::marker::Copy for DFS_INFO_8 {}
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::clone::Clone for DFS_INFO_8 {
     fn clone(&self) -> Self {
         *self
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem', 'Win32_Foundation', 'Win32_Security'*"]
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`, `\"Win32_Security\"`*"]
+#[cfg(feature = "Win32_Security")]
 pub struct DFS_INFO_9 {
     pub EntryPath: ::windows_sys::core::PWSTR,
     pub Comment: ::windows_sys::core::PWSTR,
@@ -434,44 +434,44 @@ pub struct DFS_INFO_9 {
     pub PropertyFlags: u32,
     pub MetadataSize: u32,
     pub SdLengthReserved: u32,
-    pub pSecurityDescriptor: *mut super::super::Security::SECURITY_DESCRIPTOR,
+    pub pSecurityDescriptor: super::super::Security::PSECURITY_DESCRIPTOR,
     pub NumberOfStorages: u32,
     pub Storage: *mut DFS_STORAGE_INFO_1,
 }
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::marker::Copy for DFS_INFO_9 {}
-#[cfg(all(feature = "Win32_Foundation", feature = "Win32_Security"))]
+#[cfg(feature = "Win32_Security")]
 impl ::core::clone::Clone for DFS_INFO_9 {
     fn clone(&self) -> Self {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_MOVE_FLAG_REPLACE_IF_EXISTS: u32 = 1u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub type DFS_NAMESPACE_VERSION_ORIGIN = i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_NAMESPACE_VERSION_ORIGIN_COMBINED: DFS_NAMESPACE_VERSION_ORIGIN = 0i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_NAMESPACE_VERSION_ORIGIN_SERVER: DFS_NAMESPACE_VERSION_ORIGIN = 1i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_NAMESPACE_VERSION_ORIGIN_DOMAIN: DFS_NAMESPACE_VERSION_ORIGIN = 2i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_PROPERTY_FLAG_ABDE: u32 = 32u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_PROPERTY_FLAG_CLUSTER_ENABLED: u32 = 16u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_PROPERTY_FLAG_INSITE_REFERRALS: u32 = 1u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_PROPERTY_FLAG_ROOT_SCALABILITY: u32 = 2u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_PROPERTY_FLAG_SITE_COSTING: u32 = 4u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_PROPERTY_FLAG_TARGET_FAILBACK: u32 = 8u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_RESTORE_VOLUME: u32 = 2u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_SITELIST_INFO {
     pub cSites: u32,
     pub Site: [DFS_SITENAME_INFO; 1],
@@ -483,7 +483,7 @@ impl ::core::clone::Clone for DFS_SITELIST_INFO {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_SITENAME_INFO {
     pub SiteFlags: u32,
     pub SiteName: ::windows_sys::core::PWSTR,
@@ -494,12 +494,12 @@ impl ::core::clone::Clone for DFS_SITENAME_INFO {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_SITE_PRIMARY: u32 = 1u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_STORAGE_FLAVOR_UNUSED2: u32 = 768u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_STORAGE_INFO {
     pub State: u32,
     pub ServerName: ::windows_sys::core::PWSTR,
@@ -512,7 +512,7 @@ impl ::core::clone::Clone for DFS_STORAGE_INFO {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 #[cfg(any(target_arch = "aarch64", target_arch = "x86_64"))]
 pub struct DFS_STORAGE_INFO_0_32 {
     pub State: u32,
@@ -528,7 +528,7 @@ impl ::core::clone::Clone for DFS_STORAGE_INFO_0_32 {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_STORAGE_INFO_1 {
     pub State: u32,
     pub ServerName: ::windows_sys::core::PWSTR,
@@ -541,16 +541,16 @@ impl ::core::clone::Clone for DFS_STORAGE_INFO_1 {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_STORAGE_STATES: u32 = 15u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_STORAGE_STATE_ACTIVE: u32 = 4u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_STORAGE_STATE_OFFLINE: u32 = 1u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_STORAGE_STATE_ONLINE: u32 = 2u32;
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_SUPPORTED_NAMESPACE_VERSION_INFO {
     pub DomainDfsMajorVersion: u32,
     pub DomainDfsMinorVersion: u32,
@@ -566,7 +566,7 @@ impl ::core::clone::Clone for DFS_SUPPORTED_NAMESPACE_VERSION_INFO {
     }
 }
 #[repr(C)]
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub struct DFS_TARGET_PRIORITY {
     pub TargetPriorityClass: DFS_TARGET_PRIORITY_CLASS,
     pub TargetPriorityRank: u16,
@@ -578,51 +578,51 @@ impl ::core::clone::Clone for DFS_TARGET_PRIORITY {
         *self
     }
 }
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub type DFS_TARGET_PRIORITY_CLASS = i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DfsInvalidPriorityClass: DFS_TARGET_PRIORITY_CLASS = -1i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DfsSiteCostNormalPriorityClass: DFS_TARGET_PRIORITY_CLASS = 0i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DfsGlobalHighPriorityClass: DFS_TARGET_PRIORITY_CLASS = 1i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DfsSiteCostHighPriorityClass: DFS_TARGET_PRIORITY_CLASS = 2i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DfsSiteCostLowPriorityClass: DFS_TARGET_PRIORITY_CLASS = 3i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DfsGlobalLowPriorityClass: DFS_TARGET_PRIORITY_CLASS = 4i32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_FLAVORS: u32 = 768u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_FLAVOR_AD_BLOB: u32 = 512u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_FLAVOR_STANDALONE: u32 = 256u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_FLAVOR_UNUSED1: u32 = 0u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATES: u32 = 15u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_FORCE_SYNC: u32 = 64u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_INCONSISTENT: u32 = 2u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_OFFLINE: u32 = 3u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_OK: u32 = 1u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_ONLINE: u32 = 4u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_RESYNCHRONIZE: u32 = 16u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const DFS_VOLUME_STATE_STANDBY: u32 = 32u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const FSCTL_DFS_BASE: u32 = 6u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const FSCTL_DFS_GET_PKT_ENTRY_STATE: u32 = 401340u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const NET_DFS_SETDC_FLAGS: u32 = 0u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const NET_DFS_SETDC_INITPKT: u32 = 2u32;
-#[doc = "*Required features: 'Win32_Storage_DistributedFileSystem'*"]
+#[doc = "*Required features: `\"Win32_Storage_DistributedFileSystem\"`*"]
 pub const NET_DFS_SETDC_TIMEOUT: u32 = 1u32;
